@@ -81,4 +81,7 @@ def get_ipaddr():
     """
     :return: the ip address for the current request (or 127.0.0.1 if none found)
     """
-    return request.remote_addr or '127.0.0.1'
\ No newline at end of file
+    if request.access_route:
+        return request.access_route[0]
+    else:
+        return request.remote_addr or '127.0.0.1'
\ No newline at end of file
